==> 1.2.6.zip: mysql(v_1.2.6).php <==
<?
/************************************************************
copyrigth Claudio cardinale 2004-2010 tutti i diritti riservati
contatti: 	cardi@thecsea.it(o http://www.thecsea.it)
versione :	1.2.6
data:		12/10/2010 20:37
*************************************************************/
//classe con metodi di acceso al db, passare come parametri $db_host,$db_user,$db_password,$db_name
class Mysql{ 
	//propriet private
	private $db_host = "";
	private $db_user = "";
	private $db_password = "";
	private $db_name = "";
	private $db = "";

	public function __construct($db_host,$db_user,$db_password,$db_name) {
		//assgnazione propriet
		//controllo che i parametro della funzione non siano nulli
		if ($db_host != "")
			$this->db_host = $db_host;

		if ($db_user != "")
			$this->db_user = $db_user;

		if ($db_password != "")
			$this->db_password = $db_password;

		if ($db_name != "")
			$this->db_name = $db_name;
		
		//mi conetto al db
		$this->db = mysql_connect($db_host, $db_user, $db_password) or die (/*"Connessione al database non riuscita"*/);
		mysql_select_db($db_name, $this->db) or die (/*"Selezione del database non riuscita"*/);
	}
	
	//metodi privati
	
	//ritorna la stringa sostituisce all'interno degli apici con \virgola
	private function metti_escape_virgola($stringa){
		$stringa = str_replace("\\","\\/",$stringa);
		$stringa = str_replace("\\/'","\\apice",$stringa);
		$stringa = explode("'",$stringa);
		$len = count($stringa);
		for($i=1,$j=0;$i<$len;$i+=2,$j++)
			$str[$j] = str_replace(",","\\virgola",$stringa[$i]);
		$stringa = "'".implode("','",$str)."'";
			
		
		return $stringa;
	}
	
	//toglie gli escape per la virgola
	private function togli_escape_virgola($stringa){
		$stringa = str_replace("\\virgola",",",$stringa);
		$stringa = str_replace("\\apice","\\/'",$stringa);
		return str_replace("\\/","\\",$stringa);
	}
	
	//metodi pubblici
	
	//esegue una guery
	public function esegui($query,$return=true){
	$results = mysql_query($query, $this->db);
	if (!$results)
		return false;
	else
		if($return===true)
			return $results;
		else
			return true;
	}
	
	//inserisce un record nel database
	public function inserisci ($campo, $valore, $table){
	if (($this->esegui("INSERT INTO $table ( $campo) VALUES	($valore);",false))===true)
		return true;
	else
		return false;
	}
	
	//ritorna il primo valore incrontrato nel database con una determinata condizione
	public function leggi ($valore_ritornato,$condizione,$table){
		$result = $this->esegui("SELECT $valore_ritornato FROM $table WHERE $condizione;");
		while ($row = mysql_fetch_array($result))
			return $row[$valore_ritornato];
	}

	//aggiorna un valore nel database
	public function aggiorna ($campo, $valore, $table, $condizione){
		//divisione dei parametri da aggiornare
		$valore = $this->metti_escape_virgola($valore);
		$campo = explode(",",$campo);
		$valore = explode(",",$valore);
		$len = count($campo);
		$set = "";
		for($i=0;$i<$len;$i++){
			$set .= $campo[$i]."=".$this->togli_escape_virgola($valore[$i]);
			if($i<($len-1))
				$set .= ",";
		}
		
		//agiornamento
		if ($results=$this->esegui("UPDATE $table SET $set WHERE $condizione;",false)===true)
			return true;
		return false;
	}
	
	//ritorna un elenco di valori incrontrati nel database con una determinata condizione
	public function elenca ($campo_ritornato,$condizione,$ordine,$tipo_ordine,$table,$mat=0){
		$result = $this->esegui("SELECT $campo_ritornato FROM $table WHERE $condizione ORDER BY $ordine $tipo_ordine;");
		$i = 0;
		$rit = false;
		while ($row = mysql_fetch_array($result))
			if($mat){
				for ($j =0; $j<count($row)/2;$j++ )
					$rit[$i][$j]=$row[$j];
				$i++;
			}else
				for ($j =0; $j<count($row)/2;$j++ )
					$rit[$i++]=$row[$j];
		return $rit;
	}
	
	//elimina una serie di valori dal database con una determinata condizione
	public function elimina ($condizione,$table){
		if (($this->esegui("DELETE  FROM $table WHERE $condizione;",false))===true&&mysql_affected_rows())
			return true;
		else
			return false;
			
	}
	
	//elimina una tabella dal databse
	public function elimina_tabella ($table){
		if (($this->esegui("DROP TABLE $table;",false))===true)
			return true;
		else
			return false;
	}
	
	//ritorna le info di una tabella
	public function info ($valore_ritornato,$table){
		$result = $this->esegui("show table status like '$table';");
		while ($row = mysql_fetch_array($result))
			return $row[$valore_ritornato];
	}
}
?>

==> 1.2.8.zip: mysql(v_1.2.8).php <==
<?
/************************************************************
copyrigth Claudio Cardinale 2004-2011 tutti i diritti riservati
contatti: 	cardi@thecsea.it(o http://www.thecsea.it)
versione :	1.2.8
data:		23/11/2011 00:06

per scaricare l'ultima versione andare
su http://www.thecsea.it/progetti/classi_db
non eliminare il copyright e ridistribuire
sempre il codice accompagnato dalla licenza GNU
****************************************************************/
//classe con metodi di acceso al db, passare come parametri $db_host,$db_user,$db_password,$db_name
class Mysql{ 
	//propriet private
	private $db_host = "";
	private $db_user = "";
	private $db_password = "";
	private $db_name = "";
	private $db = "";

	public function __construct($db_host = "", $db_user = "", $db_password = "", $db_name = "") {
		//assgnazione propriet
		//controllo che i parametro della funzione non siano nulli
		if ($db_host != "")
			$this->db_host = $db_host;

		if ($db_user != "")
			$this->db_user = $db_user;

		if ($db_password != "")
			$this->db_password = $db_password;

		if ($db_name != "")
			$this->db_name = $db_name;
		
		//mi conetto al db
		$this->db = @mysql_connect($db_host, $db_user, $db_password) or die ("Connessione al database non riuscita");
		@mysql_select_db($db_name, $this->db) or die ("Selezione del database non riuscita");
	}
	
	//metodi privati
	
	//ritorna la stringa sostituendo all'interno degli apici il carattere "," con \virgola e "'" con \apice
	private function metti_escape_virgola($stringa){
		$stringa = str_replace("\\","\\/",$stringa);
		$stringa = str_replace("\\/'","\\apice",$stringa);

		//eventualmente considerare divisori anche i doppi apici
		$len =  strlen($stringa);
		$apice = false;
		$str = "";
		for($i=0; $i<$len; $i++)
			if($stringa[$i] == "'"){
				if($apice)
					$apice = false;
				else
					$apice = true;
				$str .= $stringa[$i];
			}else if($stringa[$i] == ",")
				if($apice)
					$str .= "\\virgola";
				else
					$str .= $stringa[$i];
			else
					$str .= $stringa[$i];
		
		return $str;
	}
	
	//toglie gli escape per la virgola e gli apici
	private function togli_escape_virgola($stringa){
		$stringa = str_replace("\\virgola",",",$stringa);
		$stringa = str_replace("\\apice","\\/'",$stringa);
		return str_replace("\\/","\\",$stringa);
	}
	
	//metodi pubblici
	
	//esegue una guery
	public function esegui($query,$return=true){
	$results = mysql_query($query, $this->db);
	if (!$results)
		return false;
	else
		if($return===true)
			return $results;
		else
			return true;
	}
	
	//inserisce un record nel database
	public function inserisci ($campo, $valore, $table){
	if (($this->esegui("INSERT INTO $table ( $campo) VALUES	($valore);",false))===true)
		return true;
	else
		return false;
	}
	
	//ritorna il primo valore incrontrato nel database con una determinata condizione
	public function leggi ($valore_ritornato,$condizione,$table){
		$result = $this->esegui("SELECT $valore_ritornato FROM $table WHERE $condizione;");
		if($result !== false && ($row = mysql_fetch_array($result))!==false)
			return $row[$valore_ritornato];
		return false;
	}

	//aggiorna un valore nel database
	public function aggiorna ($campo, $valore, $table, $condizione){
		//divisione dei parametri da aggiornare
		$valore = $this->metti_escape_virgola($valore);
		$campo = explode(",",$campo);
		$valore = explode(",",$valore);
		$len = count($campo);
		$set = "";
		for($i=0;$i<$len;$i++){
			$set .= $campo[$i]."=".$this->togli_escape_virgola($valore[$i]);
			if($i<($len-1))
				$set .= ",";
		}
		
		//agiornamento
		
		if ($results=$this->esegui("UPDATE $table SET $set WHERE $condizione;",false)===true)
			return true;
		return false;
	}
	
	//ritorna un elenco di valori incrontrati nel database con una determinata condizione
	public function elenca ($campo_ritornato,$condizione,$ordine,$tipo_ordine,$table,$mat=0){
		$result = $this->esegui("SELECT $campo_ritornato FROM $table WHERE $condizione ORDER BY $ordine $tipo_ordine;");
		$i = 0;
		$rit = false;
		while ($row = mysql_fetch_array($result))
			if($mat){
				for ($j =0; $j<count($row)/2;$j++ )
					$rit[$i][$j]=$row[$j];
				$i++;
			}else
				for ($j =0; $j<count($row)/2;$j++ )
					$rit[$i++]=$row[$j];
		return $rit;
	}
	
	//elimina una serie di valori dal database con una determinata condizione
	public function elimina ($condizione,$table){
		if (($this->esegui("DELETE  FROM $table WHERE $condizione;",false))===true&&mysql_affected_rows())
			return true;
		else
			return false;
			
	}
	
	//elimina una tabella dal databse
	public function elimina_tabella ($table){
		if (($this->esegui("DROP TABLE $table;",false))===true)
			return true;
		else
			return false;
	}
	
	//ritorna le info di una tabella
	public function info ($valore_ritornato,$table){
		$result = $this->esegui("show table status like '$table';");
		if($result !== false && ($row = mysql_fetch_array($result))!==false)
			return isset($row[$valore_ritornato])?$row[$valore_ritornato]:false;
		return false;
	}
}
?>
